@@ -1,14 +1,17 @@
 """
 Apply manifest built by kustomize
 """
-from ..binaries import realpath, shell
+from ..helpers.binaries import binarypath, shell
+from ..helpers.download import ensure_binary
 
 
 def apply(folders, edit):
     """
     Apply manifests built by kustomize to the Kubernetes cluster
     """
-    kustomize = realpath('kustomize')
+    ensure_binary('kustomize')
+
+    kustomize = binarypath('kustomize')
     kubectl_apply = "kubectl apply -f -"
     folder_list = ' '.join(folders)
     exec_string = f"{kustomize} build {folder_list} | {kubectl_apply}"
